@@ -20,7 +20,7 @@ use Plack::Util::Accessor qw( rules handler );
 # RECOMMEND PREREQ: Ref::Util::XS
 # RECOMMEND PREREQ: Plack::Middleware::HTTPExceptions
 
-our $VERSION = 'v0.2.0';
+our $VERSION = 'v0.2.1';
 
 
 sub prepare_app {
@@ -39,11 +39,11 @@ sub prepare_app {
             sub {
                 my ($env) = @_;
                 if ( my $logger = $env->{'psgix.logger'} ) {
-                    $logger->(
+                    $logger->({
                         level   => "warn",
                         message => __PACKAGE__
                           . " Blocked $env->{REMOTE_ADDR} $env->{REQUEST_URI}"
-                    );
+                    });
                 }
                 return HTTP::Exception->throw(HTTP_BAD_REQUEST);
             }
@@ -76,7 +76,7 @@ Plack::Middleware::Security::Simple - A simple security filter for Plack
 
 =head1 VERSION
 
-version v0.2.0
+version v0.2.1
 
 =head1 SYNOPSIS
 
@@ -88,8 +88,9 @@ version v0.2.0
 
     enable "Security::Simple",
         rules => [
-            PATH_INFO => qr{^/cgi-bin/},
-            PATH_INFO => qr{\.(php|asp)$},
+            PATH_INFO       => qr{^/cgi-bin/},
+            PATH_INFO       => qr{\.(php|asp)$},
+            HTTP_USER_AGENT => qr{BadRobot},
         ];
 
    ...
@@ -106,10 +107,14 @@ scripts.
 
 =head2 rules
 
-This is a set of rules. It should be an array-reference or
+This is a set of rules. It can be a an array-reference or
 L<Hash::Match> object containing matches against keys in the Plack
 environment.
 
+It can also be a code reference for a subroutine that takes the Plack
+environment as an argument and returns a true value if there is a
+match.
+
 =head2 handler
 
 This is a function that is called when a match is found.
